import axios from "axios";
import { createLog } from "./logger";

export async function tryLimit({ action, limit = 100 }) {
  let res = null;
  let serverPass = false;
  try {
    res = await axios.get(
      `https://tcc.qmth.com.cn/rate_limit/prod/${action}/${limit}`,
      { timeout: 5 * 1000 }
    );
    serverPass = res.data.pass;

    if (!serverPass) {
      // 休眠 1 ~ 5 秒 再试

      const sleepTime = Math.random() * 4 + 1;
      console.log({ sleepTime, now: Date.now() });
      await new Promise((resolve) => setTimeout(resolve, sleepTime * 1000));
      console.log({ sleepTime, now: Date.now() });
      res = await axios.get(
        `https://tcc.qmth.com.cn/rate_limit/prod/${action}/${limit}`,
        { timeout: 5 * 1000 }
      );
      serverPass = res.data.pass;
      createLog({
        action: "限流后自动重试",
        detail: serverPass ? "进入" : "依然限流",
      });
    }
  } catch (error) {
    console.log(error);
    window._hmt.push(["_trackEvent", "在线考试列表页面", "获取rateLimit失败"]);
  }

  return serverPass;
}
